import React, { ReactElement, ReactNode } from "react";
export declare type PipeProviderProps = {
    component: ReactNode;
    children: ReactNode;
};
/**
 * A provider providing the component to be rendered on {@link Pipe}.
 *
 * @since 1.0.0
 */
export declare function PipeProvider(props: PipeProviderProps): JSX.Element;
/**
 * Return the component to be rendered on {@link Pipe}.
 *
 * @since 1.0.0
 */
export declare function usePipe(): React.ReactNode;
/**
 * Render the next component in the pipeline.
 *
 * @since 1.0.0
 */
export declare function Pipe(): JSX.Element;
/**
 * A shortcut to pass {@code <Pipe />} as the children prop.
 *
 * @since 1.0.0
 */
export declare const pipe: {
    children: JSX.Element;
};
export declare type PipelineProps = {
    components?: ReactNode[];
    children?: ReactElement | ReactElement[];
};
/**
 * Render the provided components with the last
 * component's pipe being the current pipe.
 *
 * Note: this component will add the current pipe
 * to the components list, enabling the last given
 * component to render the next component in the
 * parent pipeline.
 *
 * @since 1.0.0
 */
export declare function Pipeline(props: PipelineProps): JSX.Element;
/**
 * Render the provided components.
 *
 * Note: this component won't pass the current pipe.
 * If this was in another piping, The `<Pipe />` component
 * in this piping won't render the next component in the parent piping.
 *
 * @since 1.0.0
 */
export declare function Piping(props: {
    components?: ReactNode[];
    children?: ReactElement | ReactElement[];
    fallback?: ReactNode;
}): JSX.Element;
/**
 * Create a pipeline component from the provided components.
 *
 * Note: this component won't pass the current pipe.
 * If this was in another piping, The `<Pipe />` component
 * in this piping won't render the next component in the parent piping.
 *
 * @since 1.1.0
 */
export declare function createPipeline(components: ReactNode[], fallback?: ReactNode): JSX.Element;
